@@ -167,6 +167,9 @@ RVineMLE <- function(data, RVM, start = RVM$par, start2 = RVM$par2, maxit = 200,
     o <- diag(RVM$Matrix)
     oldRVM <- RVM
     RVM <- normalizeRVineMatrix(RVM)
+    if (is.null(colnames(data)))
+         colnames(data) <- paste0("V", 1:ncol(data))
+    cnms <- colnames(data)
     data <- data[, o[length(o):1]]
 
 
@@ -471,20 +474,18 @@ RVineMLE <- function(data, RVM, start = RVM$par, start2 = RVM$par2, maxit = 200,
         }
     }
 
-    ## list for final output
+    # list for final output
     out <- list()
-
+    # store results in out
     out$value <- out1$value
     out$convergence <- out1$convergence
     out$message <- out1$message
     out$counts <- out1$counts
-
     if (hessian == TRUE)
         out$hessian <- out1$hessian
-
     if (se == TRUE)
         out1$se <- sqrt((diag(solve(-out1$hessian))))
-
+    # create parameter matrices
     kk <- 1
     for (ll in 1:nParams) {
         out1$par[ll] <- out1$par[ll]
@@ -494,24 +495,25 @@ RVineMLE <- function(data, RVM, start = RVM$par, start2 = RVM$par2, maxit = 200,
             kk <- kk + 1
         }
     }
-
     newpar <- newpar2 <- matrix(0, d, d)
     newpar[posParams]  <- out1$par[1:nParams]
-    newpar2[posParams] <- out1$par[(nParams + 1):(nParams + nParams2)]
+    if (nParams2 > 0)
+        newpar2[posParams] <- out1$par[(nParams + 1):(nParams + nParams2)]
+    # create RVineMatrix object
     out$RVM <- RVineMatrix(Matrix = oldRVM$Matrix,
                            family = oldRVM$family,
                            par = newpar,
                            par2 = newpar2,
                            names = oldRVM$names)
-
+    # add standad errors
     if (se == TRUE) {
         out$RVM$se <- matrix(0, d, d)
         out$RVM$se2 <- matrix(0, d, d)
         out$RVM$se[posParams] <- out1$se[1:nParams]
         out$RVM$se2[posParams2] <- out1$se[(nParams + 1):(nParams + nParams2)]
     }
-
-    like <- RVineLogLik(data, out$RVM)
+    # add summary statistics
+    like <- RVineLogLik(data[, cnms], out$RVM)
     out$RVM$logLik <- like$loglik
     out$RVM$pair.logLik <- like$V$value
     npar <- sum(out$RVM$family %in% allfams[onepar], na.rm = TRUE) +
